[![CodeQL](https://github.com/elden1337/peaqev-core/actions/workflows/codeql.yml/badge.svg)](https://github.com/elden1337/peaqev-core/actions/workflows/codeql.yml) [![Python application](https://github.com/elden1337/peaqev-core/actions/workflows/python-app.yml/badge.svg)](https://github.com/elden1337/peaqev-core/actions/workflows/python-app.yml) 
[![Buy me a coffee](https://img.shields.io/static/v1.svg?label=Buy%20me%20a%20coffee&message=🥨&color=black&logo=buy%20me%20a%20coffee&logoColor=white&labelColor=6f4e37)](https://www.buymeacoffee.com/elden)

Core classes for Peaqev car charging.

https://pypi.org/project/peaqevcore/

Used in: https://github.com/elden1337/hass-peaq
